@@ -16,6 +16,16 @@ sub protected_super_prop : Method {
     return $self->protected_prop + $self->class_protected_prop;
 }
 
+sub set_readonly_super_prop : Method { 
+    $self->set_readonly_prop( 1 );
+    return $self;
+}
+
+sub set_class_readonly_super_prop : Method { 
+    $self->set_class_readonly_prop( 1 );
+    return $self;
+}
+
 sub private_super_prop : Method { 
     $self->set_private_prop( 1 );
     $self->private_prop;
